/*****************************************************************************

			       XCopilot

This code is part of XCopilot, a port of copilot

     Portions of this code are Copyright (C) 1997 Ivan A. Curtis
		       icurtis@radlogic.com.au

The original MS-Windows95 copilot emulator was written by Greg Hewgill.
The following copyright notice appeared on the original copilot sources:

		  Copyright (c) 1996 Greg Hewgill

 MC68000 Emulation code is from Bernd Schmidt's Unix Amiga Emulator.
       The following copyright notice appeared in those files:

	  Original UAE code Copyright (c) 1995 Bernd Schmidt

This code must not be distributed without these copyright notices intact.

*******************************************************************************
*******************************************************************************

Filename:	display.h

Description:	function definitions for copilot display module

Update History:   (most recent first)
     Brian Grossman 30-Jun-97 24:00 -- added pixeldoubling
     I. Curtis  25-Feb-97 21:20 -- Created.

******************************************************************************/
#include <X11/Intrinsic.h>
#include <shared.h>

extern char *xcpInitialize(shared_img *shptr, XtAppContext context, Widget topWidget, int no_x_shm,
                           int magfactor, int use_private_colormap,
                           char *BackgroundColorName,
                           char *BacklightColorName);
extern void xcpEventLoop(XtAppContext context, Widget topWidget, char *sbuf,
                         shared_img *custreg_img);
